cbind.magpie: cbind method for MAgPIE objects

View source: R/cbind.magpie.R

cbind.magpieR Documentation

cbind method for MAgPIE objects

Description

cbind method for MAgPIE-objects. Issues a warning that mbind should be used if all objects are magpie objects and continues afterwards.

Usage

## S3 method for class 'magpie'
cbind(..., deparse.level = 1)

Arguments

...

see cbind

deparse.level

see cbind

Value

A matrix as if cbind was applied to the internal vector of the MAgPIE objects

Author(s)

Patrick Rein

See Also

Other DataBinding: extend(), magpie_expand(), magpiesort(), matchDim(), mbind()


magclass documentation built on April 17, 2026, 5:07 p.m.