commonYears: commonYears

View source: R/commonYears.R

commonYearsR Documentation

commonYears

Description

Given (a list of) magclass objects, return the years (getYears) they have in common, ignoring magclass objects with 0 or 1 years.

Usage

commonYears(..., asInteger = FALSE)

Arguments

...

One or more magclass objects, or alternatively a list of magclass objects.

asInteger

Passed on to getYears. If TRUE the output format is 1995 otherwise "y1995".

Value

The years (as returned by getYears) the input objects have in common.

Author(s)

Pascal Sauer

See Also

Other TemporalOperations: convergence(), lowpass(), time_interpolate()


magclass documentation built on April 17, 2026, 5:07 p.m.