R/escapeRegex.R
escapeRegex.Rd
Escapes all symbols in a string which have a special meaning in regular expressions.
escapeRegex(x)
String or vector of strings that should be escaped.
The escaped strings.
grep
Jan Philipp Dietrich