| fulldim | R Documentation |
Deprecated: Use getItems instead.
fulldim(x, sep = ".")
x |
A MAgPIE-object |
sep |
A character separating joined dimension names |
If a MAgPIE object is created from a source with more than one data dimension, these data dimensions are combined to a single dimension. fulldim reconstructs the original dimensionality and reports it.
A list containing in the first element the dim output and in the second element the dimnames output of the reconstructed array.
Jan Philipp Dietrich
as.magpie,unwrap,wrap
Other ObjectInfo:
dimExists(),
hasCoords(),
hasSets(),
is.temporal(),
isYear(),
ncells(),
ndim(),
sameDims()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.