Skip to content

Extracts a vector containing the region of each cell of a MAgPIE-object

Usage

getRegionList(x)

getRegionList(x) <- value

Arguments

x

MAgPIE object

value

A vector with ncell elements containing the regions of each cell.

Value

A vector with ncell elements containing the region of each cell.

Functions

  • getRegionList(x) <- value: set region names

Author

Jan Philipp Dietrich

Examples


# a <- read.magpie("example.mz")
# getRegionList(a)