Extracts regions of a MAgPIE-object
Arguments
- x
MAgPIE object
- value
Vector containing the new region names of the MAgPIE objects. If you also want to change the mapping of regions to cell please use
getRegionListinstead.
See also
getYears, getNames,
getCPR, read.magpie, write.magpie,
"magpie"
Other GetterSetter:
getCPR(),
getCells(),
getComment(),
getCoords(),
getDim(),
getItems(),
getNames(),
getRegionList(),
getSets(),
getYears(),
setItems(),
setNames-methods