magpie-pmin-pmax: pmin/pmax

pmax,magpie-methodR Documentation

pmin/pmax

Description

magclass-aware pmin/pmax, which calculate the parallel minima/maxima of the input values

Usage

## S4 method for signature 'magpie'
pmax(..., na.rm = FALSE)

## S4 method for signature 'magpie'
pmin(..., na.rm = FALSE)

Arguments

...

Multiple magpie objects with dimensions that each are either the same or only contain one or no item among all objects.

na.rm

Passed to pmin

Details

pmin/pmax do not care about the order of items in a magclass object's dim. magclass pmin/pmax reorder items in each dim so they are in the same order.

Value

A new magpie object that contains the minimum/maximum of values between all the passed magpie objects.

Author(s)

Pascal Sauer, Patrick Rein


magclass documentation built on April 17, 2026, 5:07 p.m.