Brings the spatial and temporal structure of MAgPIE objects in the right order. This function is especially useful when you create new MAgPIE objects as the order typically should be correct for MAgPIE objects.
See also
"magpie"
Other DataBinding:
cbind.magpie(),
extend(),
magpie_expand(),
matchDim(),
mbind()
Examples
pop <- maxample("pop")
a <- magpiesort(pop)