mplot: mplot

View source: R/mplot.R

mplotR Documentation

mplot

Description

Get a quick visualization of the content of most magpie objects.

Usage

mplot(px, global = TRUE, total = FALSE)

Arguments

px

The magpie object to be visualized

global

Whether data should be aggregated over regions to global values.

total

Whether the total of all data values should also be visualized.

Author(s)

Pascal Sauer, Patrick Rein

See Also

Other Display: head.magpie(), maxample(), print.magpie(), show-methods, str.magpie()


magclass documentation built on April 17, 2026, 5:07 p.m.