sameDims: sameDims

View source: R/sameDims.R

sameDimsR Documentation

sameDims

Description

Checks whether magpie objects have the same items in every dimension (ignoring order).

Usage

sameDims(...)

Arguments

...

Various magpie objects

Value

A logical indicating whether the magpie objects have the same items in every dimension.

Author(s)

Pascal Sauer, Patrick Rein

See Also

Other ObjectInfo: dimExists(), fulldim(), hasCoords(), hasSets(), is.temporal(), isYear(), ncells(), ndim()


magclass documentation built on April 17, 2026, 5:07 p.m.