Show a magpie object by calling the default show method, print, or str, depending on options("magclass_show_func").
See also
Other Display:
head.magpie(),
maxample(),
mplot(),
print.magpie(),
str.magpie()
Show a magpie object by calling the default show method, print, or str, depending on options("magclass_show_func").
Other Display:
head.magpie(),
maxample(),
mplot(),
print.magpie(),
str.magpie()