unitjoin: joins a data.frame or vector of strings with variable and...

View source: R/unitjoin.R

unitjoinR Documentation

joins a data.frame or vector of strings with variable and unit separated into a data.frame with variable and unit joined as 'variable (unit)'. Use magclass::unitsplit to split them again

Description

joins a data.frame or vector of strings with variable and unit separated into a data.frame with variable and unit joined as 'variable (unit)'. Use magclass::unitsplit to split them again

Usage

unitjoin(x, unit = NULL, col = "variable")

Arguments

x

data.frame or vector of strings

unit

vector of strings. If NULL, col 'unit' in x is used

col

column name. Default: variable

Value

data.frame or vector of strings, dependent on x

See Also

Other Utility: replace_non_finite(), unitsplit()


magclass documentation built on April 17, 2026, 5:07 p.m.