withAlignedDims: withAlignedDims

View source: R/withAlignedDims.R

withAlignedDimsR Documentation

withAlignedDims

Description

(for internal use) Executes the passed function after reordering items in each dimension for all passed magpie objects

Usage

withAlignedDims(func, funcName = "anonymous func", ...)

Arguments

func

The function that should be executed with prior alignment of dimensions

funcName

The name of the resulting function, to improve error messages

Author(s)

Pascal Sauer, Patrick Rein


magclass documentation built on April 17, 2026, 5:07 p.m.