Skip to content

cbind method for MAgPIE-objects. Issues a warning that mbind should be used if all objects are magpie objects and continues afterwards.

Usage

# S3 method for class 'magpie'
cbind(..., deparse.level = 1)

Arguments

...

see cbind

deparse.level

see cbind

Value

A matrix as if cbind was applied to the internal vector of the MAgPIE objects

See also

Author

Patrick Rein