cbind method for MAgPIE-objects. Issues a warning that mbind should be used if all objects are magpie objects and continues afterwards.
Usage
# S3 method for class 'magpie'
cbind(..., deparse.level = 1)See also
Other DataBinding:
extend(),
magpie_expand(),
magpiesort(),
matchDim(),
mbind()