Given (a list of) magclass objects, return the years (getYears) they have in common, ignoring magclass objects with 0 or 1 years.
See also
Other TemporalOperations:
convergence(),
lowpass(),
time_interpolate()
Given (a list of) magclass objects, return the years (getYears) they have in common, ignoring magclass objects with 0 or 1 years.
Other TemporalOperations:
convergence(),
lowpass(),
time_interpolate()