| commonYears | R Documentation |
Given (a list of) magclass objects, return the years (getYears) they have in common, ignoring magclass objects with 0 or 1 years.
commonYears(..., asInteger = FALSE)
... |
One or more magclass objects, or alternatively a list of magclass objects. |
asInteger |
Passed on to getYears. If TRUE the output format is 1995 otherwise "y1995". |
The years (as returned by getYears) the input objects have in common.
Pascal Sauer
Other TemporalOperations:
convergence(),
lowpass(),
time_interpolate()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.