This function checks whether a dimension given by name or number exists.
See also
Other ObjectInfo:
fulldim(),
hasCoords(),
hasSets(),
is.temporal(),
isYear(),
ncells(),
ndim(),
sameDims()
This function checks whether a dimension given by name or number exists.
Other ObjectInfo:
fulldim(),
hasCoords(),
hasSets(),
is.temporal(),
isYear(),
ncells(),
ndim(),
sameDims()