dimExists: dimExists

View source: R/dimExists.R

dimExistsR Documentation

dimExists

Description

This function checks whether a dimension given by name or number exists.

Usage

dimExists(dim, x, sep = ".")

Arguments

dim

A vector of dimension numbers or dimension names which should be checked for.

x

MAgPIE object in which the dimensions should be searched for.

sep

A character separating joined dimension names.

Value

Boolean indicating whether the dimension exists or not.

Author(s)

Jan Philipp Dietrich

See Also

dimCode

Other ObjectInfo: fulldim(), hasCoords(), hasSets(), is.temporal(), isYear(), ncells(), ndim(), sameDims()

Examples


pop <- maxample("pop")
dimExists(c("t", "scenario", "blablub"), pop)


magclass documentation built on April 17, 2026, 5:07 p.m.