| dimExists | R Documentation |
This function checks whether a dimension given by name or number exists.
dimExists(dim, x, sep = ".")
dim |
A vector of dimension numbers or dimension names which should be checked for. |
x |
MAgPIE object in which the dimensions should be searched for. |
sep |
A character separating joined dimension names. |
Boolean indicating whether the dimension exists or not.
Jan Philipp Dietrich
dimCode
Other ObjectInfo:
fulldim(),
hasCoords(),
hasSets(),
is.temporal(),
isYear(),
ncells(),
ndim(),
sameDims()
pop <- maxample("pop")
dimExists(c("t", "scenario", "blablub"), pop)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.