Skip to content

Deprecated: Use getItems instead.

Usage

fulldim(x, sep = ".")

Arguments

x

A MAgPIE-object

sep

A character separating joined dimension names

Value

A list containing in the first element the dim output and in the second element the dimnames output of the reconstructed array.

Details

If a MAgPIE object is created from a source with more than one data dimension, these data dimensions are combined to a single dimension. fulldim reconstructs the original dimensionality and reports it.

Author

Jan Philipp Dietrich