Deprecated: Use getItems instead.
Value
A list containing in the first element the dim output and in the second element the dimnames output of the reconstructed array.
Details
If a MAgPIE object is created from a source with more than one data dimension, these data dimensions are combined to a single dimension. fulldim reconstructs the original dimensionality and reports it.
See also
Other ObjectInfo:
dimExists(),
hasCoords(),
hasSets(),
is.temporal(),
isYear(),
ncells(),
ndim(),
sameDims()