Function which tries to detect the dimension to which the given elems belong
Arguments
- elems
A vector of characters containing the elements that should be found in the MAgPIE object
- x
MAgPIE object in which elems should be searched for.
- fullmatch
If enabled, only dimensions which match exactly the elements provided will be returned. Otherwise, it is sufficient if elems contains a subset of the dimension.
- dimCode
If enabled, the dimCode will be returned, otherwise the name of the dimension.
See also
Other GetterSetter:
getCPR(),
getCells(),
getComment(),
getCoords(),
getItems(),
getNames(),
getRegionList(),
getRegions(),
getSets(),
getYears(),
setItems(),
setNames-methods