| getDim | R Documentation |
Function which tries to detect the dimension to which the given elems belong
getDim(elems, x, fullmatch = FALSE, dimCode = TRUE)
elems |
A vector of characters containing the elements that should be found in the MAgPIE object |
x |
MAgPIE object in which elems should be searched for. |
fullmatch |
If enabled, only dimensions which match exactly the elements provided will be returned. Otherwise, it is sufficient if elems contains a subset of the dimension. |
dimCode |
If enabled, the dimCode will be returned, otherwise the name of the dimension. |
The name or dimCode of the dimensions in which elems were found.
Jan Philipp Dietrich
mcalc,dimCode
Other GetterSetter:
getCPR(),
getCells(),
getComment(),
getCoords(),
getItems(),
getNames(),
getRegionList(),
getRegions(),
getSets(),
getYears(),
setItems(),
setNames-methods
pop <- maxample("pop")
getDim(c("AFR", "CPA"), pop)
getDim(c("AFR", "CPA"), pop, fullmatch = TRUE)
getDim(c("AFR", "CPA"), pop, dimCode = FALSE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.