Guess the resolution of the given magpie object/coordinates by looking at the minimum difference between unique sorted values. Fall back to 0.5 if guess is infinite.
Arguments
- x
A magpie object or the coordinates of a magpie object (the result of
getCoords)
See also
Other SpatialOperations:
spatRasterToDataset()