magclass-aware pmin/pmax, which calculate the parallel minima/maxima of the input values
Usage
# S4 method for class 'magpie'
pmax(..., na.rm = FALSE)
# S4 method for class 'magpie'
pmin(..., na.rm = FALSE)Arguments
- ...
Multiple magpie objects with dimensions that each are either the same or only contain one or no item among all objects.
- na.rm
Passed to
pmin
Value
A new magpie object that contains the minimum/maximum of values between all the passed magpie objects.