| pmax,magpie-method | R Documentation |
magclass-aware pmin/pmax, which calculate the parallel minima/maxima of the input values
## S4 method for signature 'magpie'
pmax(..., na.rm = FALSE)
## S4 method for signature 'magpie'
pmin(..., na.rm = FALSE)
... |
Multiple magpie objects with dimensions that each are either the same or only contain one or no item among all objects. |
na.rm |
Passed to |
pmin/pmax do not care about the order of items in a magclass
object's dim. magclass pmin/pmax reorder items in each dim so they are in the same order.
A new magpie object that contains the minimum/maximum of values between all the passed magpie objects.
Pascal Sauer, Patrick Rein
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.