A helper that restricts and expands a magpie object x to the size of a
magpie object ref. Dimension names not present in x are added and set to
the value provided by fill. Dimension names not present in ref are
cropped.
Arguments
- x
A
magpieobject to be modified.- ref
A
magpieobject used as a reference for the modification. ReturnsxifrefisNULL.- dim
Subset of dimensions for which the matching should be done. Can be either a number between 1 and 3 or a vector of these. Defaults to all dimensions (i.e.
1:3).- fill
Value to be set in new dimensions.
See also
Other DataBinding:
cbind.magpie(),
extend(),
magpie_expand(),
magpiesort(),
mbind()