| matchDim | R Documentation |
A helper that restricts and expands a magpie object x to the size of a
magpie object ref. Dimension names not present in x are added and set to
the value provided by fill. Dimension names not present in ref are
cropped.
matchDim(x, ref, dim = 1:3, fill = NA)
x |
A |
ref |
A |
dim |
Subset of dimensions for which the matching should be done. Can
be either a number between 1 and 3 or a vector of these. Defaults to all
dimensions (i.e. |
fill |
Value to be set in new dimensions. |
The modified magpie object.
Falk Benke
Other DataBinding:
cbind.magpie(),
extend(),
magpie_expand(),
magpiesort(),
mbind()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.