Skip to content

Get a quick visualization of the content of most magpie objects.

Usage

mplot(px, global = TRUE, total = FALSE)

Arguments

px

The magpie object to be visualized

global

Whether data should be aggregated over regions to global values.

total

Whether the total of all data values should also be visualized.

Author

Pascal Sauer, Patrick Rein