Get a quick visualization of the content of most magpie objects.
See also
Other Display:
head.magpie(),
maxample(),
print.magpie(),
show-methods,
str.magpie()
Get a quick visualization of the content of most magpie objects.
Other Display:
head.magpie(),
maxample(),
print.magpie(),
show-methods,
str.magpie()