| mplot | R Documentation |
Get a quick visualization of the content of most magpie objects.
mplot(px, global = TRUE, total = FALSE)
px |
The magpie object to be visualized |
global |
Whether data should be aggregated over regions to global values. |
total |
Whether the total of all data values should also be visualized. |
Pascal Sauer, Patrick Rein
Other Display:
head.magpie(),
maxample(),
print.magpie(),
show-methods,
str.magpie()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.