Select values from a MAgPIE-object
Arguments
- x
MAgPIE object
- ...
entry selections of the form
set_name=c(set_elem1,set_elem2). Alternatively a single list element containing these selections can be provided.- collapseNames
Boolean which decides whether names should be collapsed or not.
- value
values on which the selected magpie entries should be set.
Value
The reduced MAgPIE object containing only the selected entries or the full MAgPIE object in which a selection of entries was manipulated.
Details
This functions only work for MAgPIE objects with named dimensions as the dimension name (set_name) has to be used to indicate in which dimension the entries should be searched for!