Creates a new MAgPIE object
Usage
new.magpie(
cells_and_regions = "GLO",
years = NULL,
names = NULL,
fill = NA,
sort = FALSE,
sets = NULL,
unit = NULL
)Arguments
- cells_and_regions
Either the region names (e.g. "AFR"), or the cells (e.g. 1:10), or both in combination (e.g. "AFR.1"). NULL means no spatial element.
- years
dimnames for years in the format "yXXXX" or as integers. NULL means one year which is not further specified
- names
dimnames for names. NULL means one data element which is not further specified
- fill
Default value for the MAgPIE object
- sort
Bolean. Decides, wheher output should be sorted or not.
- sets
A vector of dimension names. See
getSetsfor more information.- unit
deprecated
See also
Other ObjectCreation:
clean_magpie(),
complete_magpie(),
copy.attributes()