Skip to content

Checks whether magpie objects have the same items in every dimension (ignoring order).

Usage

sameDims(...)

Arguments

...

Various magpie objects

Value

A logical indicating whether the magpie objects have the same items in every dimension.

Author

Pascal Sauer, Patrick Rein