Checks whether magpie objects have the same items in every dimension (ignoring order).
See also
Other ObjectInfo:
dimExists(),
fulldim(),
hasCoords(),
hasSets(),
is.temporal(),
isYear(),
ncells(),
ndim()
Checks whether magpie objects have the same items in every dimension (ignoring order).
Other ObjectInfo:
dimExists(),
fulldim(),
hasCoords(),
hasSets(),
is.temporal(),
isYear(),
ncells(),
ndim()