| sameDims | R Documentation |
Checks whether magpie objects have the same items in every dimension (ignoring order).
sameDims(...)
... |
Various magpie objects |
A logical indicating whether the magpie objects have the same items in every dimension.
Pascal Sauer, Patrick Rein
Other ObjectInfo:
dimExists(),
fulldim(),
hasCoords(),
hasSets(),
is.temporal(),
isYear(),
ncells(),
ndim()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.