| str.magpie | R Documentation |
str method for MAgPIE objects for conventient display of the structure of a magpie object.
## S3 method for class 'magpie'
str(object, ...)
object |
MAgPIE object |
... |
arguments to be passed to or from other methods. |
In contrast to the default str this will not show the attributes of object@.Data as these contain only a duplicate of dimnames. Also, dim is not shown, because the information it provides is implicitly included in dimnames.
Pascal Sauer
str
Other Display:
head.magpie(),
maxample(),
mplot(),
print.magpie(),
show-methods
str(maxample("pop"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.