joins a data.frame or vector of strings with variable and unit separated into a data.frame with variable and unit joined as 'variable (unit)'. Use magclass::unitsplit to split them again
Source:R/unitjoin.R
unitjoin.Rdjoins a data.frame or vector of strings with variable and unit separated into a data.frame with variable and unit joined as 'variable (unit)'. Use magclass::unitsplit to split them again
See also
Other Utility:
replace_non_finite(),
unitsplit()