unwrap: Unwrap

View source: R/unwrap.R

unwrapR Documentation

Unwrap

Description

Creates a higher dimensional array by separating all subdimensions in the third dimension of a MAgPIE object and returning them as separate dimension.

Usage

unwrap(x, sep = NULL)

Arguments

x

A MAgPIE object

sep

deprecated, please do not use anymore

Value

An array with the full dimensionality of the original data

Author(s)

Jan Philipp Dietrich

See Also

wrap,fulldim

Other MAgPIE-Conversions: as.RasterBrick(), as.SpatRaster(), as.SpatRasterDataset(), as.SpatVector(), as.array-methods, as.data.frame-methods, as_tibble.magpie(), wrap()

Examples


a <- as.magpie(array(1:6, c(3, 2), list(c("bla", "blub", "ble"), c("up", "down"))))
unwrap(a)

magclass documentation built on April 17, 2026, 5:07 p.m.