View source: R/withAlignedDims.R
| withAlignedDims | R Documentation |
(for internal use) Executes the passed function after reordering items in each dimension for all passed magpie objects
withAlignedDims(func, funcName = "anonymous func", ...)
func |
The function that should be executed with prior alignment of dimensions |
funcName |
The name of the resulting function, to improve error messages |
Pascal Sauer, Patrick Rein
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.